/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.sensor;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.Envelope;
import com.vividsolutions.jts.geom.Point;
import com.vividsolutions.jts.geom.impl.CoordinateArraySequence;
import nl.cloudfarming.client.geoviewer.Geographical;
import org.geotools.coverage.grid.GridCoverage2D;
import org.geotools.geometry.jts.JTSFactoryFinder;

/**
 * Grid for sensor files
 * @author Merijn Zengers
 */
public class SensorGrid implements Geographical<GridCoverage2D> {

    private final SensorProcessor processor;
    private GridCoverage2D coverage;

    public SensorGrid(SensorProcessor processor) {
        this.processor = processor;
    }

    @Override
    public Point getCentroid() {
        if (coverage != null) {
            Double x = coverage.getEnvelope2D().getCenterX();
            Double y = coverage.getEnvelope2D().getCenterY();
            return new Point(new CoordinateArraySequence(new Coordinate[]{new Coordinate(x, y)}), JTSFactoryFinder.getGeometryFactory(null));
        }
        return null;
    }

    @Override
    public GridCoverage2D getRenderObject(Envelope envelope) {
        if (coverage == null) {
            coverage = RasterFactory.createRaster(processor.process());
        }
        return coverage;
    }

    @Override
    public String getTooltipText() {
        return "";
    }

    @Override
    public long getId() {
        return 1l;
    }
}
